pub struct System;Trait Implementations
Sourceimpl AccountDeserialize for System
impl AccountDeserialize for System
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self, ProgramError>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self, ProgramError>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(_buf: &mut &[u8]) -> Result<Self, ProgramError>
fn try_deserialize_unchecked(_buf: &mut &[u8]) -> Result<Self, ProgramError>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.